pub struct CircularMaterial { /* private fields */ }Trait Implementations
Sourceimpl AsBindGroup for CircularMaterial
impl AsBindGroup for CircularMaterial
type Param = (Res<'static, RenderAssets<GpuImage>>, Res<'static, FallbackImage>, Res<'static, RenderAssets<GpuShaderStorageBuffer>>)
Sourcefn unprepared_bind_group(
&self,
layout: &BindGroupLayout,
render_device: &RenderDevice,
(images, fallback_image, storage_buffers): &mut SystemParamItem<'_, '_, Self::Param>,
force_no_bindless: bool,
) -> Result<UnpreparedBindGroup<Self::Data>, AsBindGroupError>
fn unprepared_bind_group( &self, layout: &BindGroupLayout, render_device: &RenderDevice, (images, fallback_image, storage_buffers): &mut SystemParamItem<'_, '_, Self::Param>, force_no_bindless: bool, ) -> Result<UnpreparedBindGroup<Self::Data>, AsBindGroupError>
Returns a vec of (binding index,
OwnedBindingResource). Read moreSourcefn bind_group_layout_entries(
render_device: &RenderDevice,
force_no_bindless: bool,
) -> Vec<BindGroupLayoutEntry>
fn bind_group_layout_entries( render_device: &RenderDevice, force_no_bindless: bool, ) -> Vec<BindGroupLayoutEntry>
Returns a vec of bind group layout entries. Read more
fn bindless_descriptor() -> Option<BindlessDescriptor>
Sourcefn bindless_slot_count() -> Option<BindlessSlabResourceLimit>
fn bindless_slot_count() -> Option<BindlessSlabResourceLimit>
The number of slots per bind group, if bindless mode is enabled. Read more
Sourcefn bindless_supported(_: &RenderDevice) -> bool
fn bindless_supported(_: &RenderDevice) -> bool
True if the hardware actually supports bindless textures for this
type, taking the device and driver capabilities into account. Read more
Sourcefn as_bind_group(
&self,
layout: &BindGroupLayout,
render_device: &RenderDevice,
param: &mut <Self::Param as SystemParam>::Item<'_, '_>,
) -> Result<PreparedBindGroup<Self::Data>, AsBindGroupError>
fn as_bind_group( &self, layout: &BindGroupLayout, render_device: &RenderDevice, param: &mut <Self::Param as SystemParam>::Item<'_, '_>, ) -> Result<PreparedBindGroup<Self::Data>, AsBindGroupError>
Creates a bind group for
self matching the layout defined in AsBindGroup::bind_group_layout.Sourcefn bind_group_layout(render_device: &RenderDevice) -> BindGroupLayoutwhere
Self: Sized,
fn bind_group_layout(render_device: &RenderDevice) -> BindGroupLayoutwhere
Self: Sized,
Creates the bind group layout matching all bind groups returned by
AsBindGroup::as_bind_groupSourceimpl Clone for CircularMaterial
impl Clone for CircularMaterial
Sourcefn clone(&self) -> CircularMaterial
fn clone(&self) -> CircularMaterial
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CircularMaterial
impl Debug for CircularMaterial
Sourceimpl TypePath for CircularMaterial
impl TypePath for CircularMaterial
Sourcefn type_path() -> &'static str
fn type_path() -> &'static str
Returns the fully qualified path of the underlying type. Read more
Sourcefn short_type_path() -> &'static str
fn short_type_path() -> &'static str
Returns a short, pretty-print enabled path to the type. Read more
Sourcefn type_ident() -> Option<&'static str>
fn type_ident() -> Option<&'static str>
Sourcefn crate_name() -> Option<&'static str>
fn crate_name() -> Option<&'static str>
Sourceimpl UiMaterial for CircularMaterial
impl UiMaterial for CircularMaterial
Sourcefn fragment_shader() -> ShaderRef
fn fragment_shader() -> ShaderRef
Returns this materials fragment shader. If
ShaderRef::Default is returned, the default
UI fragment shader will be used.Sourcefn vertex_shader() -> ShaderRef
fn vertex_shader() -> ShaderRef
Returns this materials vertex shader. If
ShaderRef::Default is returned, the default UI
vertex shader will be used.fn specialize( descriptor: &mut RenderPipelineDescriptor, key: UiMaterialKey<Self>, )
Sourceimpl VisitAssetDependencies for CircularMaterial
impl VisitAssetDependencies for CircularMaterial
fn visit_dependencies(&self, visit: &mut impl FnMut(UntypedAssetId))
impl Asset for CircularMaterial